@@ -12,9 +12,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import base64
 import io
 import logging
-from re import I
 import tarfile
 import time
 import typing
@@ -46,6 +46,7 @@ def create_container(
     name: "str",
     image: "str" = None,
     image_driver: "str" = DEFAULT_IMAGE_DRIVER,
+    device_profiles: "list[str]" = None,
     environment: "dict" = None,
     exposed_ports: "list[str]" = [],
     runtime: "str" = None,
@@ -67,6 +68,11 @@ def create_container(
             image. Defaults to "docker", meaning the image is assumed to be a
             Docker registry repository. Specify "glance" to launch a snapshot
             image by passing the Glance Image ID in the ``image`` argument.
+        device_profiles (list[str]): An optional list of device profiles to
+            request be configured on the container when it is created. Edge
+            devices may have differing sets of supported device profiles, so
+            it is important to understand which profiles are supported by the
+            target device for your container.
         environment (dict): A set of environment variables to pass to the
             container.
         exposed_ports (list[str]): A list of ports to expose on the container.
@@ -110,6 +116,7 @@ def create_container(
         image=image,
         image_driver=image_driver,
         nets=nets,
+        device_profiles=device_profiles,
         exposed_ports={port_def: {} for port_def in (exposed_ports or [])},
         environment=environment,
         runtime=runtime,
@@ -226,6 +233,20 @@ def upload(container_ref: "str", source: "str", dest: "str") -> "dict":
     return zun().containers.put_archive(container_ref, dest, data)
 
 
+def download(container_ref: "str", source: "str", dest: "str"):
+    """Download a file or directory from a running container.
+
+    Args:
+        container_ref (str): The name or ID of the container.
+        source (str): The (container) path of the file or directory.
+        dest (str): The (local) path to download to.
+    """
+    res = zun().containers.get_archive(container_ref, source)
+    fd = io.BytesIO(base64.b64decode(res["data"]))
+    with tarfile.open(fileobj=fd, mode="r") as tar:
+        tar.extractall(dest)
+
+
 def wait_for_active(container_ref: "str", timeout: int = (60 * 2)) -> "Container":
     """Wait for a container to transition to the running state.
 
@@ -249,7 +270,9 @@ def _wait_for_status(
 
     while True:
         container = get_container(container_ref)
-        if container.status == status:
+        if container.status == "Error":
+            raise RuntimeError("Container went in to error state")
+        elif container.status == status:
             return container
         time.sleep(5)
         if time.perf_counter() - start_time >= timeout:
